@@ -180,6 +180,12 @@ class TsTable:
         
         return min_ts
 
+    def min_dt(self):
+        return self.__ts_to_dt(self.__get_min_ts())
+
+    def max_dt(self):
+        return self.__ts_to_dt(self.__get_min_ts())
+
     def read_range(self,start_dt,end_dt,as_pandas_dataframe=True):
         # Convert start_dt and end_dt to UTC if they are naive
         if start_dt.tzinfo is None:
@@ -188,8 +194,8 @@ class TsTable:
             end_dt = pytz.utc.localize(end_dt)
 
 
-        if start_dt < end_dt:
-            raise AttributeError('start_dt must be >= end_dt')
+        if start_dt > end_dt:
+            raise AttributeError('start_dt must be <= end_dt')
         
 
         partitions = self.__dtrange_to_partition_ranges(start_dt,end_dt)
